#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-6joFVU7K3iDGbWieeMVwFp
key:                  heapsize-0.3.0.1-6joFVU7K3iDGbWieeMVwFp
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  4ee8e61e8eb5fa3d68edeb1755cc9463
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-8.10.5/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/heapsize-0.3.0.1
hs-libraries:         HSheapsize-0.3.0.1-6joFVU7K3iDGbWieeMVwFp
depends:
    base-4.14.2.0 deepseq-1.4.4.0 exceptions-0.10.4 ghc-heap-8.10.5
    hashable-1.3.2.0-GpzwVyCMdDv8NwdC61S1EE
    hashtables-1.2.4.1-43zoxjuV2LAL5nNA3NSXHl
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh transformers-0.5.6.2
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

